@@ -153,7 +153,7 @@ sspreg91 <- function(s,r,q,y,cov,method,alpha,varht)
                       as.double(.Machine$double.eps),
                       chol=double(nn*nn), double(nn),
                       jpvt=as.integer(c(rep(1,nnull),rep(0,nxi))),
-                      wk=double(nobs+nnull), rkv=integer(1), info=integer(1),
+                      wk=double(3*nobs+nnull), rkv=integer(1), info=integer(1),
                       PACKAGE="gss")[c("score","varht","dc","chol","jpvt","wk","rkv","info")]
         if (z$info) stop("gss error in ssanova9: evaluation of GML score fails")
         if (!nnull|method%in%c("u","v")) detw <- 2*sum(log(diag(ww)))
@@ -214,12 +214,14 @@ sspreg91 <- function(s,r,q,y,cov,method,alpha,varht)
         y.wk <- forwardsolve(t(ww),y)
         s.wk <- forwardsolve(t(ww),s)
         r.wk <- forwardsolve(t(ww),r)
+        mn0 <- log.la0-6
+        mx0 <- log.la0+6
         repeat {
-            mn <- la-1
-            mx <- la+1
-            if (mx>log.la0+6) break
+            mn <- max(la-1,mn0)
+            mx <- min(la+1,mx0)
             zz <- nlm0(cv,c(mn,mx))
-            if (min(zz$est-mn,mx-zz$est)>=1e-3) break
+            if ((min(zz$est-mn,mx-zz$est)>=1e-1)||
+                (min(zz$est-mn0,mx0-zz$est)<1e-1)) break
             else la <- zz$est
         }
     }
@@ -288,7 +290,7 @@ mspreg91 <- function(s,r,id.basis,y,cov,method,alpha,varht,skip.iter)
                       as.double(.Machine$double.eps),
                       chol=double(nn*nn), double(nn),
                       jpvt=as.integer(c(rep(1,nnull),rep(0,nxi))),
-                      wk=double(nobs+nnull), rkv=integer(1), info=integer(1),
+                      wk=double(3*nobs+nnull), rkv=integer(1), info=integer(1),
                       PACKAGE="gss")[c("score","varht","dc","chol","jpvt","wk","rkv","info")]
         if (z$info) stop("gss error in ssanova9: evaluation of GML score fails")
         if (!nnull|method%in%c("u","v")) detw <- 2*sum(log(diag(ww)))
