@@ -219,7 +219,7 @@ sspdsty <- function(s,r,q,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha,bias)
                         cd=as.double(cd), as.integer(nxis),
                         as.double(10^(lambda+theta)*q), as.integer(nxi),
                         as.double(rbind(10^theta*r,s)), as.integer(nobs),
-                        as.integer(sum(cnt)), as.integer(cnt),
+                        as.double(sum(cnt)), as.double(cnt),
                         as.double(t(rbind(10^theta*qd.r,qd.s))), as.integer(nqd),
                         as.integer(bias$nt), as.double(bias$wt),
                         as.double(t(qd.wt*bias$qd.wt)),
@@ -306,7 +306,7 @@ mspdsty <- function(s,r,id.basis,cnt,qd.s,qd.r,qd.wt,prec,maxiter,alpha,bias,ski
                         cd=as.double(cd), as.integer(nxis),
                         as.double(10^lambda*q.wk), as.integer(nxi),
                         as.double(rbind(r.wk0,s)), as.integer(nobs),
-                        as.integer(sum(cnt)), as.integer(cnt),
+                        as.double(sum(cnt)), as.double(cnt),
                         as.double(t(rbind(qd.r.wk0,qd.s))), as.integer(nqd),
                         as.integer(bias$nt), as.double(bias$wt),
                         as.double(t(qd.wt*bias$qd.wt)),
